@@ -59,7 +59,7 @@ class BOOZ_XFORM(SortedDict):
         """
         import xarray
 
-        vmec = xarray.open_dataset(wout, "r")
+        vmec = xarray.open_dataset(wout)
         ind = wout.index("wout_") + 5
         end = wout.index(".nc")
         extension = wout[ind:end]
@@ -73,13 +73,14 @@ class BOOZ_XFORM(SortedDict):
         vmec.close()
         return BOOZ_XFORM.write_input(extension, mbooz, nbooz, surfaces)
 
-    def plot(self, ordering=0, mn=(None, None), ax=None, **kwargs):
+    def plot(self, ordering=0, mn=(None, None), ax=None, log=True, **kwargs):
         """Plot |B| components 1D profile
 
         Args:
             ordering (integer, optional): Plot the leading Nordering asymmetric modes. Defaults to 0.
             mn (tuple, optional): Plot the particular (m,n) mode. Defaults to (None, None).
             ax (Matplotlib axis, optional): Matplotlib axis to be plotted on. Defaults to None.
+            log (bool, optional): Plot in log scale. Default to True.
             kwargs (dict): Keyword arguments for matplotlib.pyplot.plot. Defaults to {}.
 
         Returns:
@@ -87,12 +88,12 @@ class BOOZ_XFORM(SortedDict):
         """
         xx = self.jlist / self.ns
         return self.plot_helicity(
-            self.bmnc, self.xm, self.xn, xx, ordering, mn, ax, **kwargs
+            self.bmnc, self.xm, self.xn, xx, ordering, mn, ax, log, **kwargs
         )
 
     @staticmethod
     def plot_helicity(*args, **kwargs):
-        vals, xm, xn, xx, ordering, mn, ax = args
+        vals, xm, xn, xx, ordering, mn, ax, log = args
         # get figure and ax data
         if ax is None:
             fig, ax = plt.subplots()
@@ -106,8 +107,13 @@ class BOOZ_XFORM(SortedDict):
                 ind = ind_arg[-1 - i]  # index of the i-th largest term
                 m = xm[ind]
                 n = xn[ind]
-                kwargs["label"] = "m={:}, n={:}".format(m, n)
-                ax.semilogy(xx, vals[:, ind], **kwargs)
+                if m==0 and n==0:
+                    continue
+                kwargs["label"] = "m={:}, n={:}".format(int(m), int(n))
+                if log:
+                    ax.semilogy(xx, np.abs(vals[:, ind]), **kwargs)
+                else:
+                    ax.plot(xx, np.abs(vals[:, ind]), **kwargs)
             ylabel = r"$\frac{B_{m,n}}{ \Vert B_{n=0} \Vert }$"
         else:
             # determine filter condition
@@ -126,7 +132,10 @@ class BOOZ_XFORM(SortedDict):
             cond = np.logical_and(mfilter, nfilter)
             # data = np.reshape(vals[:, cond], (ns, -1))
             data = vals[:, cond]
-            line = ax.semilogy(xx, np.linalg.norm(data, axis=1), **kwargs)
+            if log:
+                line = ax.semilogy(xx, np.linalg.norm(data, axis=1), **kwargs)
+            else:
+                line = ax.plot(xx, np.linalg.norm(data, axis=1), **kwargs)
             ylabel = r"$ \frac{{ \Vert B_{{ {:},{:} }} \Vert }}{{ \Vert B_{{n=0}} \Vert }} $".format(
                 m, n
             )
